@@ -1,9 +1,79 @@
-import matplotlib.pyplot as plt
-from matplotlib.animation import FuncAnimation
-import numpy as np
-import json
+"""
+# Game Of Life
 
-from lexicon import *
+Simple way to play Conway's game of life in python.
+You can import your own map as json file name "save.json", using `get_MAP` methode.
+All you custom maps (in the save.json file) are available in the list `custom_maps`.
+Other custom maps are available such as: `my_map_1` and `my_map_2`, created using `Map` class : 
+
+>>> from simple_game_of_life import Map
+>>> m = Map(100)
+>>> my_map_1 = m.mini_random_MAP((25, 20))
+>>> my_map_2 = m.kind(kind="line 10")
+
+
+NOTE : Two artificials borders are created for each map, 
+The first one is visible while playing, it's in black.
+The second one is white (invisible) just after the black border, no cell can born here
+
+
+## Installation
+
+Run the following command to install:
+```$ pip install simple-game-of-life ```
+
+
+## Usage
+
+for a random map :
+>>> from simple_game_of_life import GameOfLife
+>>> game = GameOfLife(50) 
+>>> game.start_animation()
+
+
+for a custom map : 
+>>> from simple_game_of_life import GameOfLife
+>>> from random import choice
+>>> custom_map = GameOfLife.get_MAP() # custom_map already saved in the json file
+>>> game = GameOfLife(custom_map=choice(my_custom_map))
+>>> game.start_animation()
+>>> # Note you can also import custom_map like that :
+>>> # from simple_game_of_life import custom_map 
+
+to implement a pattern :
+>>> from simple_game_of_life import GameOfLife, Map
+>>> glider = [[0,1,0],
+              [0,0,1],
+              [1,1,1]]
+>>> m = Map(100)
+>>> my_map = m.my_pattern(glider)
+>>> game = GameOfLife(custom_map=my_map)
+>>> game.start_animation()
+
+
+## Other usage
+
+`GameOfLife` classe :
+    - You can save a map by using `saved_MAP` methode.
+    - You can get a map by using `get_MAP` methode.
+    - You can reset all saved map by using `reset_MAP` methode.
+    - You can get all frames by using `get_history` methode.
+    - You can set a new animation with the same instance using `new_animation` methode.
+
+
+`Map` classe :
+    - `full_random_MAP` : all the map gonna be random.
+    - `mini_random_MAP` : a portion of the map gonna be random.
+    - `my_pattern` : insert your pattern into an empty map.
+    - `kind` : insert well know pattern into an empty map, (currenly 5 patterns are available).
+
+
+You can also calculate the average time of instancing, using `timeit` function:
+
+>>> game = timeit(GameOfLife, loop=100, size_or_side=50, frames=200) # loop : number of loop
+>>> game.start_animation()
+
+"""
 
 ###################################################################################################
 
@@ -29,17 +99,28 @@ from lexicon import *
 # and remains alive as long as it has two or three living neighbors
 # otherwise it dies (by isolation or overpopulation)
 
-
 ##################################################################################################
 
+import matplotlib.pyplot as plt
+from matplotlib.animation import FuncAnimation
+import numpy as np
+import json
+
+from lexicon import *
+
+
 class Map:
     def __init__(self, size_or_side):
-        """_summary_
+        """simple way to create a map :
+                - `full_random_MAP` : all the map gonna be random.
+                - `mini_random_MAP` : a portion of the map gonna be random.
+                - `my_pattern` : insert your pattern into an empty map
+                - `kind` : insert well know pattern into an empty map, (currenly 5 patterns are available)
 
         Args:
             size_or_side ((iterable, lenght = 2) or int):
             either size of a matrix 
-            or side of a square matrix. 
+            or side (width, height) of a square matrix. 
 
             kind (str, optional): 
             Lexicon of well know pattern, ex 'line 10' is a line of 10 living cell. 
@@ -64,6 +145,15 @@ class Map:
         self.map[x_map+x_rest: -x_map, y_map + y_rest:-y_map] = pattern
 
     def full_random_MAP(self, seed=None):
+        """all the map gonna be random.
+
+        Args:
+
+            seed (_type_, optional): set the seed, by using `np.random.seed`. Defaults to None.
+
+        Returns:
+            map : all the map gonna be random.
+        """
 
         if seed != None:
             np.random.seed(seed)
@@ -72,6 +162,18 @@ class Map:
         return map_
 
     def mini_random_MAP(self, size_or_side, seed=None):
+        """a portion of the map gonna be random.
+
+        Args:
+            size_or_side ((iterable, lenght = 2) or int): 
+            either size of a matrix 
+            or side (width, height) of a square matrix.
+
+            seed (_type_, optional): set the seed, by using `np.random.seed`. Defaults to None.
+
+        Returns:
+            map : a portion of the map gonna be random.
+        """
 
         if seed is not None:
             np.random.seed(seed)
@@ -83,11 +185,19 @@ class Map:
         return self.map
 
     def my_pattern(self, pattern):
+        """insert your pattern into an empty map
+
+        Args:
+            pattern (matrix): the pattern you whant to insert into a empty map
+
+        Returns:
+            map: the map with you pattern in the middle, without border
+        """
         self._insert(pattern)
         return self.map
 
     def kind(self, kind: str = None):
-        """_summary_
+        """insert well know pattern
 
         Args:
             kind (str, optional): 
@@ -122,7 +232,7 @@ class Map:
 
 ##################################################################################################
 
-class JeuDeLaVie:  # GameOfLife :)
+class GameOfLife:
     """
     Simple way to play Conway's game of life in python.
     You can import your own map as json file name "save.json", using `get_MAP` methode.
@@ -168,7 +278,7 @@ class JeuDeLaVie:  # GameOfLife :)
         Args:
             size_or_side ((iterable, lenght = 2) or int):
             either size of a matrix 
-            or side of a square matrix. 
+            or side (width, height) of a square matrix. 
             Defaults to None.
 
             custom_map (iterable, matrix): 
@@ -227,7 +337,6 @@ class JeuDeLaVie:  # GameOfLife :)
         self.fig = fig
         self.ax = ax
         self.im = im
-        return fig, ax, im
 
     def random_MAP(self):
 
@@ -309,7 +418,9 @@ class JeuDeLaVie:  # GameOfLife :)
 
         Args:
             size_or_side ((iterable, lenght = 2) or int):
-            size or side of the new map, for random map. Defaults to None.
+            either size of a matrix 
+            or side (width, height) of a square matrix. 
+            Defaults to None.
 
             new_custom_map (iterable, matrix):
             new custom map. Defaults to None.
@@ -404,11 +515,11 @@ class JeuDeLaVie:  # GameOfLife :)
                 maps = json.load(f)
             return maps
         except:
-            pass
+            return []
 
     @staticmethod
     def get_MAP():
-        return JeuDeLaVie._init_saved_MAP()
+        return GameOfLife._init_saved_MAP()
 
     def save_MAP(self):
         if self.is_history_avalide:
@@ -425,17 +536,9 @@ class JeuDeLaVie:  # GameOfLife :)
             pass
             # dont need to do anything, save.json will be reset
 
-
 ###################################################################################################
 
 
-class GameOfLife(JeuDeLaVie):
-    def __init__(self, size_or_side=None, custom_map=None, seed=None, frames=500, zoom=10):
-        super().__init__(size_or_side, custom_map, seed, frames, zoom)
-
-
-###################################################################################################
-
 def _size_or_side(size_or_side):
 
     assert (_is_iterable(size_or_side) and len(size_or_side) == 2) or (
@@ -470,6 +573,7 @@ def timeit(cls, loop: int = 10, **kw):
     # let n and i be a natural number != 0
     # if i is n*10% of loop => i/loop = n*0.1 => i/loop/0.1 = n ∈ N*
 
+    T_tot = time()
     L = []
     print(f"calculating the average time of instancing over {loop} loop")
     for i in range(1, loop + 1):
@@ -479,7 +583,8 @@ def timeit(cls, loop: int = 10, **kw):
         if i / loop / 0.1 >= n:  # take the first iteration greater than n*10%
             n += 1
             print(f"processing {i / loop * 100:.2f}%")
-    print(f"average of {mean(L):.2f} per loop")
+    print(f"average of {mean(L):.2f}s per loop",
+          "\n", f"Total time : {time()-T_tot:.2f}")
     return game
 
 
